import { ViewContainerRef, Component, ComponentFactoryResolver, ChangeDetectorRef } from "@angular/core";
import { write } from "trace";
export const CATEGORY = "detached-loader";
function log(message) {
    write(message, CATEGORY);
}
/**
 * Wrapper component used for loading components when navigating
 * It uses DetachedContainer as selector so that it is containerRef is not attached to
 * the visual tree.
 */
export let DetachedLoader = class DetachedLoader {
    constructor(resolver, changeDetector, containerRef) {
        this.resolver = resolver;
        this.changeDetector = changeDetector;
        this.containerRef = containerRef;
    }
    loadInLocation(componentType) {
        const factory = this.resolver.resolveComponentFactory(componentType);
        const componentRef = this.containerRef.createComponent(factory, this.containerRef.length, this.containerRef.parentInjector);
        // Component is created, buit may not be checked if we are loading
        // inside component with OnPush CD strategy. Mark us for check to be sure CD will reach us.
        // We are inside a promise here so no need for setTimeout - CD should trigger
        // after the promise.
        log("DetachedLoader.loadInLocation component loaded -> markForCheck");
        this.changeDetector.markForCheck();
        return Promise.resolve(componentRef);
    }
    detectChanges() {
        this.changeDetector.markForCheck();
    }
    // TODO: change this API -- async promises not needed here anymore.
    loadComponent(componentType) {
        log("DetachedLoader.loadComponent");
        return this.loadInLocation(componentType);
    }
    loadWithFactory(factory) {
        return this.containerRef.createComponent(factory, this.containerRef.length, this.containerRef.parentInjector, null);
    }
};
DetachedLoader = __decorate([
    Component({
        selector: "DetachedContainer",
        template: `<Placeholder #loader></Placeholder>`
    }), 
    __metadata('design:paramtypes', [ComponentFactoryResolver, ChangeDetectorRef, ViewContainerRef])
], DetachedLoader);
//# sourceMappingURL=detached-loader.js.map