import { ReflectiveInjector, ComponentFactoryResolver, Injectable, Directive } from "@angular/core";
import { Page } from "ui/page";
import { DetachedLoader } from "../common/detached-loader";
import { PAGE_FACTORY } from "../platform-providers";
export class ModalDialogParams {
    constructor(context = {}, closeCallback) {
        this.context = context;
        this.closeCallback = closeCallback;
    }
}
let ModalDialogService_1 = class ModalDialogService {
    showModal(type, options) {
        if (!options.viewContainerRef) {
            throw new Error("No viewContainerRef: Make sure you pass viewContainerRef in ModalDialogOptions.");
        }
        const viewContainerRef = options.viewContainerRef;
        const parentPage = viewContainerRef.injector.get(Page);
        const resolver = viewContainerRef.injector.get(ComponentFactoryResolver);
        const pageFactory = viewContainerRef.injector.get(PAGE_FACTORY);
        return new Promise((resolve) => {
            setTimeout(() => ModalDialogService_1.showDialog(type, options, resolve, viewContainerRef, resolver, parentPage, pageFactory), 10);
        });
    }
    static showDialog(type, options, doneCallback, containerRef, resolver, parentPage, pageFactory) {
        const page = pageFactory({ isModal: true, componentType: type });
        let detachedLoaderRef;
        const closeCallback = (...args) => {
            doneCallback.apply(undefined, args);
            page.closeModal();
            detachedLoaderRef.instance.detectChanges();
            detachedLoaderRef.destroy();
        };
        const modalParams = new ModalDialogParams(options.context, closeCallback);
        const providers = ReflectiveInjector.resolve([
            { provide: Page, useValue: page },
            { provide: ModalDialogParams, useValue: modalParams },
        ]);
        const childInjector = ReflectiveInjector.fromResolvedProviders(providers, containerRef.parentInjector);
        const detachedFactory = resolver.resolveComponentFactory(DetachedLoader);
        detachedLoaderRef = containerRef.createComponent(detachedFactory, -1, childInjector, null);
        detachedLoaderRef.instance.loadComponent(type).then((compRef) => {
            const componentView = compRef.location.nativeElement;
            if (componentView.parent) {
                componentView.parent.removeChild(componentView);
            }
            page.content = componentView;
            parentPage.showModal(page, options.context, closeCallback, options.fullscreen);
        });
    }
};
export let ModalDialogService = ModalDialogService_1;
ModalDialogService = ModalDialogService_1 = __decorate([
    Injectable(), 
    __metadata('design:paramtypes', [])
], ModalDialogService);
export let ModalDialogHost = class ModalDialogHost {
    constructor() {
        throw new Error("ModalDialogHost is deprecated. Call ModalDialogService.showModal() " +
            "by passing ViewContainerRef in the options instead.");
    }
};
ModalDialogHost = __decorate([
    Directive({
        selector: "[modal-dialog-host]" // tslint:disable-line:directive-selector
    }), 
    __metadata('design:paramtypes', [])
], ModalDialogHost);
//# sourceMappingURL=dialogs.js.map