import { ElementRef, Directive, Input, TemplateRef, ViewContainerRef } from "@angular/core";
import { TabViewItem } from "ui/tab-view";
import { convertToInt } from "../common/utils";
import { rendererLog } from "../trace";
import { isBlank } from "../lang-facade";
export let TabViewDirective = class TabViewDirective {
    constructor(element) {
        this.tabView = element.nativeElement;
    }
    get selectedIndex() {
        return this._selectedIndex;
    }
    set selectedIndex(value) {
        this._selectedIndex = convertToInt(value);
        if (this.viewInitialized) {
            this.tabView.selectedIndex = this._selectedIndex;
        }
    }
    ngAfterViewInit() {
        this.viewInitialized = true;
        rendererLog("this._selectedIndex: " + this._selectedIndex);
        if (!isBlank(this._selectedIndex)) {
            this.tabView.selectedIndex = this._selectedIndex;
        }
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Number)
], TabViewDirective.prototype, "selectedIndex", null);
TabViewDirective = __decorate([
    Directive({
        selector: "TabView",
    }), 
    __metadata('design:paramtypes', [ElementRef])
], TabViewDirective);
export let TabViewItemDirective = class TabViewItemDirective {
    constructor(owner, templateRef, viewContainer) {
        this.owner = owner;
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
    }
    get title() {
        return this._title;
    }
    set title(value) {
        if (this._title !== value) {
            this._title = value;
            this.ensureItem();
            this.item.title = this._title;
        }
    }
    get iconSource() {
        return this._iconSource;
    }
    set iconSource(value) {
        if (this._iconSource !== value) {
            this._iconSource = value;
            this.ensureItem();
            this.item.iconSource = this._iconSource;
        }
    }
    ensureItem() {
        if (!this.item) {
            this.item = new TabViewItem();
        }
    }
    ngOnInit() {
        this.ensureItem();
        if (this.config) {
            this.item.title = this._title || this.config.title;
            this.item.iconSource = this._iconSource || this.config.iconSource;
        }
        const viewRef = this.viewContainer.createEmbeddedView(this.templateRef);
        // Filter out text nodes, etc
        const realViews = viewRef.rootNodes.filter((node) => node.nodeName && node.nodeName !== "#text");
        if (realViews.length > 0) {
            this.item.view = realViews[0];
            const newItems = (this.owner.tabView.items || []).concat([this.item]);
            this.owner.tabView.items = newItems;
        }
    }
};
__decorate([
    Input("tabItem"), 
    __metadata('design:type', Object)
], TabViewItemDirective.prototype, "config", void 0);
__decorate([
    // tslint:disable-line:no-input-rename
    Input(), 
    __metadata('design:type', Object)
], TabViewItemDirective.prototype, "title", null);
__decorate([
    Input(), 
    __metadata('design:type', Object)
], TabViewItemDirective.prototype, "iconSource", null);
TabViewItemDirective = __decorate([
    Directive({
        selector: "[tabItem]" // tslint:disable-line:directive-selector
    }), 
    __metadata('design:paramtypes', [TabViewDirective, TemplateRef, ViewContainerRef])
], TabViewItemDirective);
//# sourceMappingURL=tab-view.js.map