import { Injectable } from "@angular/core";
import { Http, ConnectionBackend, ResponseOptions, ResponseType, Response } from "@angular/http";
import { Observable } from "rxjs/Observable";
import "rxjs/add/observable/fromPromise";
import { NSFileSystem } from "../file-system/ns-file-system";
export class NSXSRFStrategy {
    configureRequest(_req) {
        // noop
    }
}
export let NSHttp = class NSHttp extends Http {
    constructor(backend, defaultOptions, nsFileSystem) {
        super(backend, defaultOptions);
        this.nsFileSystem = nsFileSystem;
    }
    /**
     * Performs a request with `get` http method.
     * Uses a local file if `~/` resource is requested.
     */
    get(url, options) {
        if (url.indexOf("~") === 0 || url.indexOf("/") === 0) {
            // normalize url
            url = url.replace("~", "").replace("/", "");
            // request from local app resources
            return Observable.fromPromise(new Promise((resolve, reject) => {
                let app = this.nsFileSystem.currentApp();
                let localFile = app.getFile(url);
                if (localFile) {
                    localFile.readText().then((data) => {
                        resolve(responseOptions(data, 200, url));
                    }, (err) => {
                        reject(responseOptions(err, 400, url));
                    });
                }
                else {
                    reject(responseOptions("Not Found", 404, url));
                }
            }));
        }
        else {
            return super.get(url, options);
        }
    }
};
NSHttp = __decorate([
    Injectable(), 
    __metadata('design:paramtypes', [ConnectionBackend, Object, NSFileSystem])
], NSHttp);
function responseOptions(body, status, url) {
    return new Response(new ResponseOptions({
        body: body,
        status: status,
        statusText: "OK",
        type: status === 200 ? ResponseType.Default : ResponseType.Error,
        url: url
    }));
}
//# sourceMappingURL=ns-http.js.map