import { Directive, ElementRef, forwardRef, HostListener } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { isBlank } from "../lang-facade";
import { BaseValueAccessor } from "./base-value-accessor";
const CHECKED_VALUE_ACCESSOR = { provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => CheckedValueAccessor), multi: true };
/**
 * The accessor for setting a checked property and listening to changes that is used by the
 * {@link NgModel} directives.
 *
 *  ### Example
 *  ```
 *  <Switch [(ngModel)]="model.test">
 *  ```
 */
export let CheckedValueAccessor = class CheckedValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    checkedChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        let normalizedValue = false;
        if (!isBlank(value)) {
            if (typeof value === "string") {
                normalizedValue = value.toLowerCase() === "true" ? true : false;
            }
            else {
                normalizedValue = !!value;
            }
        }
        this.view.checked = normalizedValue;
    }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    // tslint:disable-line:directive-class-suffix
    HostListener("checkedChange", ["$event"]), 
    __metadata('design:type', Function), 
    __metadata('design:paramtypes', [Object]), 
    __metadata('design:returntype', void 0)
], CheckedValueAccessor.prototype, "checkedChangeListener", null);
CheckedValueAccessor = __decorate([
    Directive({
        // tslint:disable-next-line:max-line-length directive-selector
        selector: "Switch[ngModel], Switch[formControlName], switch[ngModel], switch[formControlName], switch[ngModel], switch[formControlName]",
        providers: [CHECKED_VALUE_ACCESSOR]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], CheckedValueAccessor);
//# sourceMappingURL=checked-value-accessor.js.map