import { Directive, ElementRef, forwardRef, HostListener } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { isBlank, isDate } from "../lang-facade";
import { BaseValueAccessor } from "./base-value-accessor";
const DATE_VALUE_ACCESSOR = { provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => DateValueAccessor), multi: true };
/**
 * The accessor for setting a date and listening to changes that is used by the
 * {@link NgModel} directives.
 *
 *  ### Example
 *  ```
 *  <DatePicker [(ngModel)]="model.test">
 *  ```
 */
export let DateValueAccessor = class DateValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    dateChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        let normalizedValue = isBlank(value) ? new Date() : value;
        if (!isDate(normalizedValue)) {
            if (typeof normalizedValue === "string") {
                normalizedValue = new Date(normalizedValue);
            }
            else if (typeof normalizedValue === "number") {
                normalizedValue = new Date(normalizedValue);
            }
            if (!isDate(normalizedValue)) {
                normalizedValue = new Date();
            }
        }
        this.view.date = normalizedValue;
    }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    // tslint:disable-line:directive-class-suffix
    HostListener("dateChange", ["$event"]), 
    __metadata('design:type', Function), 
    __metadata('design:paramtypes', [Object]), 
    __metadata('design:returntype', void 0)
], DateValueAccessor.prototype, "dateChangeListener", null);
DateValueAccessor = __decorate([
    Directive({
        // tslint:disable-next-line:max-line-length directive-selector
        selector: "DatePicker[ngModel], DatePicker[formControlName], datePicker[ngModel], datePicker[formControlName], date-picker[ngModel], date-picker[formControlName]",
        providers: [DATE_VALUE_ACCESSOR]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], DateValueAccessor);
//# sourceMappingURL=date-value-accessor.js.map