import { Directive, ElementRef, forwardRef, HostListener } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { isBlank, isNumber } from "../lang-facade";
import { BaseValueAccessor } from "./base-value-accessor";
const NUMBER_VALUE_ACCESSOR = { provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NumberValueAccessor), multi: true };
/**
 * The accessor for setting a value and listening to changes that is used by the
 * {@link NgModel}
 *
 *  ### Example
 *  ```
 *  <Slider [(ngModel)]="model.test">
 *  ```
 */
export let NumberValueAccessor = class NumberValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    valueChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        let normalizedValue;
        if (isBlank(value)) {
            normalizedValue = 0;
        }
        else {
            if (isNumber(value)) {
                normalizedValue = value;
            }
            else {
                let parsedValue = Number(value);
                normalizedValue = isNaN(parsedValue) ? 0 : parsedValue;
            }
        }
        this.view.value = normalizedValue;
    }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    // tslint:disable-line:directive-class-suffix
    HostListener("valueChange", ["$event"]), 
    __metadata('design:type', Function), 
    __metadata('design:paramtypes', [Object]), 
    __metadata('design:returntype', void 0)
], NumberValueAccessor.prototype, "valueChangeListener", null);
NumberValueAccessor = __decorate([
    Directive({
        // tslint:disable-next-line:max-line-length directive-selector
        selector: "Slider[ngModel], Slider[formControlName], slider[ngModel], slider[formControlName], slider[ngModel], slider[formControlName]",
        providers: [NUMBER_VALUE_ACCESSOR]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], NumberValueAccessor);
//# sourceMappingURL=number-value-accessor.js.map