import { Directive, ElementRef, forwardRef, HostListener } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { BaseValueAccessor } from "./base-value-accessor";
import { convertToInt } from "../common/utils";
const SELECTED_INDEX_VALUE_ACCESSOR = { provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => SelectedIndexValueAccessor), multi: true };
/**
 * The accessor for setting a selectedIndex and listening to changes that is used by the
 * {@link NgModel} directives.
 *
 *  ### Example
 *  ```
 *  <SegmentedBar [(ngModel)]="model.test">
 *  ```
 */
export let SelectedIndexValueAccessor = class SelectedIndexValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    selectedIndexChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        this._normalizedValue = convertToInt(value);
        if (this.viewInitialized) {
            this.view.selectedIndex = this._normalizedValue;
        }
    }
    ngAfterViewInit() {
        this.viewInitialized = true;
        this.view.selectedIndex = this._normalizedValue;
    }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    // tslint:disable-line:max-line-length directive-class-suffix
    HostListener("selectedIndexChange", ["$event"]), 
    __metadata('design:type', Function), 
    __metadata('design:paramtypes', [Object]), 
    __metadata('design:returntype', void 0)
], SelectedIndexValueAccessor.prototype, "selectedIndexChangeListener", null);
SelectedIndexValueAccessor = __decorate([
    Directive({
        // tslint:disable-next-line:max-line-length directive-selector
        selector: "SegmentedBar[ngModel], SegmentedBar[formControlName], segmentedBar[ngModel], segmentedBar[formControlName], segmented-bar[ngModel], segmented-bar[formControlName], ListPicker[ngModel], ListPicker[formControlName], listPicker[ngModel], listPicker[formControlName], list-picker[ngModel], list-picker[formControlName], TabView[ngModel], TabView[formControlName], tabView[ngModel], tabView[formControlName], tab-view[ngModel], tab-view[formControlName]",
        providers: [SELECTED_INDEX_VALUE_ACCESSOR]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], SelectedIndexValueAccessor);
//# sourceMappingURL=selectedIndex-value-accessor.js.map