import { Directive, ElementRef, forwardRef, HostListener } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { isBlank } from "../lang-facade";
import { BaseValueAccessor } from "./base-value-accessor";
const TEXT_VALUE_ACCESSOR = { provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => TextValueAccessor), multi: true };
/**
 * The accessor for writing a text and listening to changes that is used by the
 * {@link NgModel} directives.
 *
 *  ### Example
 *  ```
 *  <TextField [(ngModel)]="model.test">
 *  ```
 */
export let TextValueAccessor = class TextValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    textChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        let normalizedValue = isBlank(value) ? "" : value.toString();
        this.view.text = normalizedValue;
    }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    // tslint:disable-line:directive-class-suffix
    HostListener("textChange", ["$event"]), 
    __metadata('design:type', Function), 
    __metadata('design:paramtypes', [Object]), 
    __metadata('design:returntype', void 0)
], TextValueAccessor.prototype, "textChangeListener", null);
TextValueAccessor = __decorate([
    Directive({
        // tslint:disable-next-line:max-line-length directive-selector
        selector: "TextField[ngModel], TextField[formControlName], textField[ngModel], textField[formControlName], text-field[ngModel], text-field[formControlName], TextView[ngModel], TextView[formControlName], textView[ngModel], textView[formControlName], text-view[ngModel], text-view[formControlName], SearchBar[ngModel], SearchBar[formControlName], searchBar[ngModel], searchBar[formControlName], search-bar[ngModel], search-bar[formControlName]",
        providers: [TEXT_VALUE_ACCESSOR]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], TextValueAccessor);
//# sourceMappingURL=text-value-accessor.js.map